<?php

namespace KINGSTROXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;
use Elementor\Utils;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Blog_Grid extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kingstrox_blog_grid';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Blog Grid', 'kingstrox' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-post';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kingstrox' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'blog_grid',
			[
				'label' => esc_html__( 'Blog Grid', 'kingstrox' ),
			]
		);

		$this->add_control(
			'style',
			[
				'label'   => esc_html__( 'Select Style', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'style1',
				'options' => array(
					'style1'   => esc_html__( 'Style One', 'rashid' ),
					'style2'   => esc_html__( 'Style Two', 'rashid' ),
					'style3'   => esc_html__( 'Style Three', 'rashid' ),
					'style4'   => esc_html__( 'Style Four', 'rashid' ),
					'style5'   => esc_html__( 'Style Five', 'rashid' ),
				),
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);	

		$this->add_control(
				'btnlink',
				[
				'label' => __( 'Button Url', 'rashid' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'rashid' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
				
			]
		);

		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'rashid' ),
				'default' => esc_html__('Read More', 'rashid'),
			]
		);

		$this->add_control(
            'thumb', 
				[
					'label'   => esc_html__( 'Choose Post Image', 'constech' ),
					'label_block' => true,
					'type'    => Controls_Manager::SELECT,
					'default' => 'style1',
					'options' => array(
						'style1' => esc_html__( 'Meta Box Image', 'constech' ),
						'style2' => esc_html__( 'Dafult Thumbnail', 'constech' ),
					),
				]
		);
		
		
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'kingstrox' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'kingstrox' ),
				'default' => esc_html__('Read More', 'kingstrox'),
			]
		);	
		$this->add_control(
			'column',
			[
				'label'   => esc_html__( 'Column', 'kingstrox' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '3',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'kingstrox' ),
					'6'   => esc_html__( 'Two Column', 'kingstrox' ),
					'4'   => esc_html__( 'Three Column', 'kingstrox' ),
					'3'   => esc_html__( 'Four Column', 'kingstrox' ),
					'2'   => esc_html__( 'Six Column', 'kingstrox' ),
				),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		
		
		$this->end_controls_section();
	
		$this->start_controls_section(
				'content_section',
				[
					'label' => __( 'Blog Block', 'kingstrox' ),
					'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				]
			);
			
		
		$this->add_control(
			'text_limit',
			[
				'label'   => esc_html__( 'Text Limit', 'kingstrox' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 15,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_number',
			[
				'label'   => esc_html__( 'Number of post', 'kingstrox' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
		$this->add_control(
			'query_orderby',
			[
				'label'   => esc_html__( 'Order By', 'kingstrox' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'date',
				'options' => array(
					'date'       => esc_html__( 'Date', 'kingstrox' ),
					'title'      => esc_html__( 'Title', 'kingstrox' ),
					'menu_order' => esc_html__( 'Menu Order', 'kingstrox' ),
					'rand'       => esc_html__( 'Random', 'kingstrox' ),
				),
			]
		);
		$this->add_control(
			'query_order',
			[
				'label'   => esc_html__( 'Order', 'kingstrox' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'DESC',
				'options' => array(
					'DESc' => esc_html__( 'DESC', 'kingstrox' ),
					'ASC'  => esc_html__( 'ASC', 'kingstrox' ),
				),
			]
		);
		$this->add_control(
			'query_exclude',
			[
				'label'       => esc_html__( 'Exclude', 'kingstrox' ),
				'type'        => Controls_Manager::TEXT,
				'description' => esc_html__( 'Exclude posts, pages, etc. by ID with comma separated.', 'kingstrox' ),
			]
		);
		$this->add_control(
            'query_category', 
				[
				  'type' => Controls_Manager::SELECT,
				  'label' => esc_html__('Category', 'kingstrox'),
				  'options' => get_blog_categories()
				]
		);

		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'rashid' ),
				'default' => esc_html__('Read More', 'rashid'),
			]
		);	
		
		$this->end_controls_section();

	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
        
        $paged = kingstrox_set($_POST, 'paged') ? esc_attr($_POST['paged']) : 1;

		$this->add_render_attribute( 'wrapper', 'class', 'templatepath-kingstrox' );
		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => kingstrox_set( $settings, 'query_number' ),
			'orderby'        => kingstrox_set( $settings, 'query_orderby' ),
			'order'          => kingstrox_set( $settings, 'query_order' ),
			'paged'         => $paged
		);
		if ( kingstrox_set( $settings, 'query_exclude' ) ) {
			$settings['query_exclude'] = explode( ',', $settings['query_exclude'] );
			$args['post__not_in']      = kingstrox_set( $settings, 'query_exclude' );
		}
		if( kingstrox_set( $settings, 'query_category' ) ) $args['category_name'] = kingstrox_set( $settings, 'query_category' );
		$query = new \WP_Query( $args );

		if ( $query->have_posts() ) 
		{ ?>


	<!-- News Section -->
	<?php  if ( 'style1' === $settings['style'] ) : ?>	
	<section class="news-section <?php echo esc_attr($settings['sec_class']);?>">
		<div class="auto-container">
			<?php if($settings['title']): ?>
			<div class="clearfix">
				<div class="sec-title">
					<span class="title"><?php echo $settings['subtitle'];?></span>
					<h2><?php echo $settings['title'];?></h2>
				</div>

				<div class="btn-box">
					<a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="theme-btn btn-style-one"><?php echo $settings['bttn'];?></a>
				</div>
			</div>
			<?php endif; ?>

			<div class="row">
				<?php while ( $query->have_posts() ) : $query->the_post();
					$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
					?>

					<!-- News BLock -->
					<div class="news-block col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-6 col-sm-12 wow fadeInUp">
						<div class="inner-box">
							<div class="image-box">
								<figure class="image">
									<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
										<?php  if ( 'style1' === $settings['thumb'] ) : ?>
										<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
										<?php endif; ?> 
										<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
										<?php  the_post_thumbnail();    ?>
										<?php endif; ?> 
									</a>
								</figure>
							</div>
							<div class="lower-content">
								<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><span class="date"><?php echo get_the_date(); ?></span></a>
								<h3>
									<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a>
								</h3>
								<div class="text"><?php echo kingstrox_trim(get_the_content(), $settings['text_limit']); ?></div>
								<div class="link-box">
									<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php echo $settings['bttn'];?></a>
								</div>
							</div>
						</div>
					</div>
				<?php endwhile; ?>  
			</div>
		</div>
	</section>
	<?php endif;?>
    <!--End News Section -->


	<!-- News Section Two -->
	<?php  if ( 'style2' === $settings['style'] ) : ?>
    <section class="news-section-two p-0 <?php echo esc_attr($settings['sec_class']);?>">
        <div class="auto-container">
            <div class="row">
			<?php while ( $query->have_posts() ) : $query->the_post();
					$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
					?>
                <div class="news-column col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-12 col-sm-12">
                    <div class="inner-column">
                        <div class="news-block-two wow fadeInLeft">
                            <div class="inner-box row no no-gutters">
                                <div class="image-column col-lg-5 col-md-6">
                                    <figure class="image">
										<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
											<?php  if ( 'style1' === $settings['thumb'] ) : ?>
											<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
											<?php endif; ?> 
											<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
											<?php  the_post_thumbnail();    ?>
											<?php endif; ?> 
										</a>
                                    </figure>
                                </div>
                                <div class="content-column col-lg-7 col-md-6">
                                    <div class="inner">
                                        <div class="date"><span><?php echo get_the_date(); ?></span> <?php the_author(); ?></div>
                                        <h3><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h3>
                                        <div class="text"><?php echo kingstrox_trim(get_the_content(), $settings['text_limit']); ?></div>
                                        <div class="link-box"><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php echo $settings['bttn'];?></a></div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
				<?php endwhile; ?>  
            </div>
        </div>
    </section>
	<?php endif;?>
    <!--End News Section -->

	<!-- News Section Two -->
	<?php  if ( 'style3' === $settings['style'] ) : ?>
    	<section class="news-section-two p-0 <?php echo esc_attr($settings['sec_class']);?>">
			<div class="auto-container">
				<div class="row">
					<?php while ( $query->have_posts() ) : $query->the_post();
							$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
							?>
						<div class="news-list col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-12 col-sm-12">
							<div class="inner-column">
								<!-- News Block Three -->
								<div class="news-block-three">
									<div class="date"><span><?php echo get_the_date(); ?></span> <?php the_author(); ?></div>
									<h5><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h5>
								</div>

								<!-- News Block Three -->
								<div class="news-block-three">
									<div class="date"><span><?php echo get_the_date(); ?></span> <?php the_author(); ?></div>
									<h5><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h5>
								</div>

								<!-- News Block Three -->
								<div class="news-block-three">
									<div class="date"><span><?php echo get_the_date(); ?></span> <?php the_author(); ?></div>
									<h5><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h5>
								</div>
							</div>

							<div class="btn-box">
								<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>" class="theme-btn btn-style-one"><?php echo $settings['bttn'];?></a>
							</div>
						</div>
					<?php endwhile; ?>  
				</div>
			</div>
		</section>
	<?php endif;?>
    <!--End News Section -->



	 <!-- News Section Three -->
	 <?php  if ( 'style4' === $settings['style'] ) : ?>
	 <section class="news-section-three p-0 <?php echo esc_attr($settings['sec_class']);?>">
        <div class="auto-container">
            <div class="row">
				<?php while ( $query->have_posts() ) : $query->the_post();
					$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
					?>
                <div class="news-block-four col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-12 col-sm-12 wow fadeInUp">
                    <div class="inner-box">
                        <div class="image-box">
                            <figure class="image">
								<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
									<?php  if ( 'style1' === $settings['thumb'] ) : ?>
									<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
									<?php endif; ?> 
									<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
									<?php  the_post_thumbnail();    ?>
									<?php endif; ?> 
								</a>
							</figure>
                        </div>
                        <div class="lower-content">
                            <div class="date"><span><?php echo get_the_date(); ?></span> <?php the_author(); ?></div>
                            <h5><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h5>
                        </div>
                    </div>
                </div>
				<?php endwhile; ?>   
            </div>
        </div>
    </section>
	<?php endif;?>
    <!--End News Section -->

			
	<!-- Sidebar Page Container -->
	<?php  if ( 'style5' === $settings['style'] ) : ?>
    <div class="sidebar-page-container <?php echo esc_attr($settings['sec_class']);?>">
        <div class="auto-container">
            <div class="row">       
				<?php while ( $query->have_posts() ) : $query->the_post();
				$meta_image = get_post_meta( get_the_id(), 'meta_image', true );
				?>
					<div class="news-block-four col-lg-<?php echo esc_attr($settings['column'], true );?> col-md-12 col-sm-12 wow fadeInUp">
						<div class="inner-box">
							<div class="image-box">
								<figure class="image">
									<a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>">
										<?php  if ( 'style1' === $settings['thumb'] ) : ?>
										<img src="<?php echo wp_get_attachment_url($meta_image['id']);?>" alt="" />
										<?php endif; ?> 
										<?php  if ( 'style2' === $settings['thumb'] ) : ?>      
										<?php  the_post_thumbnail();    ?>
										<?php endif; ?> 
									</a>
								</figure>
							</div>
							<div class="lower-content">
								<div class="date"><span><?php echo get_the_date(); ?></span> <?php the_author(); ?></div>
								<h5><a href="<?php echo esc_url( the_permalink( get_the_id() ) );?>"><?php the_title(); ?></a></h5>
							</div>
						</div>
					</div>
				<?php endwhile; ?>  
            </div>
        </div>
    </div>
    <!-- End Sidebar Page container -->
	<?php endif;?>
        <?php }
		wp_reset_postdata();
	}

}