<?php

namespace KINGSTROXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Fun_Facts extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kingstrox_fun_facts';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Fun Facts', 'kingstrox' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kingstrox' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */

	 protected function register_controls() {
		$this->start_controls_section(
			'fun_facts',
			[
				'label' => esc_html__( 'Fun Facts', 'kingstrox' ),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);

		$this->add_control(
			'bgimg',
			[
				'label' => esc_html__('Background image', 'rashid'),
				'type' => Controls_Manager::MEDIA,
				'default' => ['url' => Utils::get_placeholder_image_src(),],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);


		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'icons',
				[
					'label' => esc_html__('Enter The icons', 'rashid'),
					'type' => Controls_Manager::ICONS,
				]
		);

		$this->add_control(
			'ff_stop',
			[
			'label' => __( 'Counter Stop', 'bitfix' ),
			'type' => Controls_Manager::TEXTAREA,
			'dynamic' => [
			'active' => true,
			],
			'placeholder' => __( 'Enter Counter Stop', 'bitfix' ),
			]
		);

		$this->add_control(
			'text2',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'title2',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);

		$this->add_control(
			'icons2',
				[
					'label' => esc_html__('Enter The icons', 'rashid'),
					'type' => Controls_Manager::ICONS,
				]
		);

		$this->add_control(
			'ff_stop1',
			[
			'label' => __( 'Counter Stop', 'bitfix' ),
			'type' => Controls_Manager::TEXTAREA,
			'dynamic' => [
			'active' => true,
			],
			'placeholder' => __( 'Enter Counter Stop', 'bitfix' ),
			]
		);

		$this->add_control(
			'text3',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'title3',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);




		$this->end_controls_section();

		// New Tab#1

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'kingstrox' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'kingstrox')],
					],

				'fields' => 
					[	

							'block_btnlink'=>
						[
							'name' => 'block_btnlink',
							'label' => __( 'Button Url', 'rashid' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'rashid' ),
							'show_external' => true,
							'default' => [
							  'url' => '',
							  'is_external' => true,
							  'nofollow' => true,
							],
						 ],

							'block_image'=>
						[
							'name' => 'block_image',
							'label' => __( 'Image', 'rashid' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

							'block_alt_text'=>
						[
						  'name' => 'block_alt_text',
						  'label' => esc_html__('Image Text', 'rashid'),
						  'type' => Controls_Manager::TEXTAREA,
						  'default' => esc_html__('', 'rashid')
						],


					],
				'title_field' => '{{block_title}}',
			 ]
			);

		$this->end_controls_section();

	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	 protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

	<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 


// Sponsors Carousel
	if ($(".sponsors-carousel").length) {
		$(".sponsors-carousel").owlCarousel({
			loop:true,
			margin:30,
			nav:false,
			smartSpeed: 500,
			autoplay: true,
			responsive:{
				0:{
					items:1
				},
				480:{
					items:2
				},
				600:{
					items:3
				},
				768:{
					items:4
				},
				1024:{
					items:4
				}
			}
		});    		
	}


//put the code above the line 

  });
</script>';
?>

	<!-- Funfacts And Clients -->
    <section class="fun-facts-and-clients <?php echo esc_attr($settings['sec_class']);?>" style="background-image: url(<?php echo wp_get_attachment_url($settings['bgimg']['id']);?>);">
        <div class="auto-container">
            <div class="row">
                <div class="funfact-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <div class="content-box">
                            <div class="sec-title">
                                <h2><?php echo $settings['title'];?></h2>
                            </div>
                            <div class="text">
								<?php echo $settings['text'];?></div>

                            <div class="bottom-box">
                                <div class="row">
                                    <!--Column-->

									<div class="counter-column col-lg-6 col-md-6 col-sm-12">										
										<div class="inner">
											<div class="icon-box">
												<span class="icon <?php echo str_replace("icon ", "", esc_attr( $settings['icons']['value']));?>"></span>
											</div>
											<div class="count-box">
												<span class="count-text" data-speed="3000" data-stop="<?php echo esc_attr($settings['ff_stop']);?>"><?php echo $settings['text2'];?></span>
											</div>
											<h4 class="counter-title"><?php echo $settings['title2'];?></h4>
										</div>										
									</div>
									<!--Column-->
                                    <div class="counter-column col-lg-6 col-md-6 col-sm-12">
										<div class="inner">
											<div class="icon-box">
												<span class="icon <?php echo str_replace("icon ", "", esc_attr( $settings['icons2']['value']));?>"></span>
											</div>
											<div class="count-box">
												<span class="count-text" data-speed="3000" data-stop="<?php echo esc_attr($settings['ff_stop1']);?>"><?php echo $settings['text3'];?></span>
											</div>
											<h4 class="counter-title"><?php echo $settings['title3'];?></h4>
										</div>	
                                    </div>
								</div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Clients Column -->
                <div class="clients-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <div class="sponsors-outer">
                            <!--Sponsors Carousel-->
                            <ul class="sponsors-carousel owl-carousel owl-theme">
								<?php foreach($settings['repeat'] as $key=>$item):?>
									<li class="slide-item">
										<figure class="image">
											<a href="<?php echo esc_url($item['block_btnlink']['url']);?>">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
													<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text '], $allowed_tags);?>">
													<?php else :?>
													<div class="noimage"></div>
												<?php endif;?>
											</a>
										</figure>
									</li>
								<?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!--End Funfacts And Clients -->

		<?php 
	}

}