<?php

namespace KINGSTROXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Service_Tab extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kingstrox_service_tab';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service Tab', 'kingstrox' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kingstrox' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'service_tab',
			[
				'label' => esc_html__( 'Service Tab', 'kingstrox' ),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);

		$this->add_control(
			'text',
			[
				'label'       => __( 'Description Text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);

		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'rashid' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);

		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => esc_html__( 'Enter your Button Title', 'rashid' ),
				'default' => esc_html__('Read More', 'rashid'),
			]
		);	

		
		$this->end_controls_section();
		

		// New Tab#1

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'kingstrox' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'kingstrox')],
					],
				'fields' => 
					[				

							'block_title'=>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

							'block_image'=>
						[
							'name' => 'block_image',
							'label' => __( 'Image', 'rashid' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],
						
							'block_alt_text'=>
						[
						  'name' => 'block_alt_text',
						  'label' => esc_html__('Image Text', 'rashid'),
						  'type' => Controls_Manager::TEXTAREA,
						  'default' => esc_html__('', 'rashid')
						],

							'block_icons'=>
						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],

							'block_btnlink'=>
						[
							'name' => 'block_btnlink',
							'label' => __( 'Button Url', 'rashid' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'rashid' ),
							'show_external' => true,
							'default' => [
							  'url' => '',
							  'is_external' => true,
							  'nofollow' => true,
							],
						],

							'block_title2'=>
						[
							'name' => 'block_title2',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

							'block_text'=>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

							'block_btnlink'=>
						[
							'name' => 'block_btnlink',
							'label' => __( 'Button Url', 'rashid' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'rashid' ),
							'show_external' => true,
							'default' => [
							  'url' => '',
							  'is_external' => true,
							  'nofollow' => true,
							],
						],


							'block_button'=>
						[
							'name' => 'block_button',
							'label'       => __( 'Button', 'rashid' ),
							'type'        => Controls_Manager::TEXT,
							'dynamic'     => [
								'active' => true,
							],
							'placeholder' => __( 'Enter your Button Title', 'rashid' ),
							'default' => esc_html__('Read More', 'rashid'),
						],

							
					],
				'title_field' => '{{block_title}}',
			 ]
			);
		
		
		$this->end_controls_section();	
			
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>


		 <!-- Services Section Four -->
		 <section class="services-section-four">
        <div class="auto-container">
            <div class="sec-title">
                <span class="title"><?php echo $settings['subtitle'];?></span>
                <h2><?php echo $settings['title'];?></h2>
            </div>
            <div class="tabs-box services-tab">
                <div class="row">
                    <!-- Text Column -->
                    <div class="text-column col-lg-4 col-md-12 col-sm-12">
                        <div class="inner-column">
                            <div class="text"><?php echo $settings['text'];?></div>

                            <!--Tabs Box-->
                            <ul class="tab-buttons clearfix">
								<?php foreach($settings['repeat'] as $key=>$item):?>
                                	<li class="tab-btn <?php if($key == 3) echo 'active-btn';?>" data-tab="#tab-<?php echo esc_attr($key);?>"><?php echo wp_kses($item['block_title'], $allowed_tags);?></li>
								<?php endforeach; ?>
                            </ul>

                            <div class="btn-box">
                                <a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="theme-btn btn-style-one"><?php echo $settings['bttn'];?></a>
                            </div>
                        </div>
                    </div>

                    <!-- Services Column -->
                    <div class="service-column col-lg-8 col-md-12 col-sm-12">
                        <div class="inner-column">
                            <div class="tabs-content">
                                <!--Tab-->
								<?php foreach($settings['repeat'] as $key=>$item):?>	
									<div class="tab <?php if($key == 3) echo 'active-tab';?>" id="tab-<?php echo esc_attr($key);?>">
										<div class="image-box">
											<figure class="image">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
												<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
												<?php else :?>
												<div class="noimage"></div>
												<?php endif;?>
											</figure>
										</div>
										<!-- Service Block -->
										<div class="service-block-four">
											<div class="inner-box">
												<span class="icon <?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></span>
												<h3><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_title2'], $allowed_tags);?></a></h3>
												<div class="text"><?php echo wp_kses($item['block_text'], $allowed_tags);?></div>
												<div class="link-box"><a href="<?php echo esc_url($item['block_btnlink']['url']);?>"><?php echo wp_kses($item['block_button'], $allowed_tags);?></a></div>
											</div>
										</div>
									</div>
								<?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End Services Section Four -->

		<?php 
	}

}