<?php

namespace KINGSTROXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Slider extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kingstrox_slider';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Slider', 'kingstrox' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kingstrox' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'slider',
			[
				'label' => esc_html__( 'Slider', 'kingstrox' ),
			]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'kingstrox' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'kingstrox' ),
			]
		);
		
		
		$this->end_controls_section();
		
		// New Tab#1

		$this->start_controls_section(
					'content_section',
					[
						'label' => __( 'Slider Block', 'kingstrox' ),
						'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
				);
				$this->add_control(
				  'repeat', 
					[
						'type' => Controls_Manager::REPEATER,
						'seperator' => 'before',
						'default' => 
							[
								['block_title' => esc_html__('Projects Completed', 'kingstrox')],
							],
						'fields' => 
							[				
								
								'block_bgimg'=>		
							[
								'name' => 'block_bgimg',
								'label' => esc_html__('Background image', 'kingstrox'),
								'type' => Controls_Manager::MEDIA,
								'default' => ['url' => Utils::get_placeholder_image_src(),],
							],
							
															
								'block_title'=>	
							[
								'name' => 'block_title',
								'label' => esc_html__('Title', 'kingstrox'),
								'type' => Controls_Manager::TEXTAREA,
								'default' => esc_html__('', 'kingstrox')
							],
							
								'block_text'=>
							
							[
								'name' => 'block_text',
								'label' => esc_html__('Text', 'kingstrox'),
								'type' => Controls_Manager::TEXTAREA,
								'default' => esc_html__('', 'kingstrox')
							],		
								
								'block_button'=>

							[
								'name' => 'block_button',
								'label'       => __( 'Button', 'kingstrox' ),
								'type'        => Controls_Manager::TEXT,
								'dynamic'     => [
									'active' => true,
								],
								'placeholder' => __( 'Enter your Button Title', 'kingstrox' ),
								'default' => esc_html__('Read More', 'kingstrox'),
							],

								'block_btnlink'=>
							
							[
								'name' => 'block_btnlink',
								'label' => __( 'Button Url', 'kingstrox' ),
								'type' => Controls_Manager::URL,
								'placeholder' => __( 'https://your-link.com', 'kingstrox' ),
								'show_external' => true,
								'default' => [
								'url' => '',
								'is_external' => true,
								'nofollow' => true,
								],
							],
									
							],
						'title_field' => '{{block_title}}',
					 ]
			);
				
				
		$this->end_controls_section();	
					
		
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

	<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 
if ($(".banner-slider").length > 0) {
	// Banner Slider
	var bannerSlider = new Swiper(".banner-slider", {
		preloadImages: false,
		loop: true,
		grabCursor: true,
		centeredSlides: false,
		resistance: true,
		resistanceRatio: 0.6,
		speed: 2400,
		spaceBetween: 0,
		parallax: false,
		effect: "slide",
		autoplay: {
			delay: 8000,
			disableOnInteraction: false
		},
		navigation: {
			nextEl: ".banner-slider-button-next",
			prevEl: ".banner-slider-button-prev",
		},
	});
}
//put the code above the line 

  });
</script>';


?>

	<section class="banner-section <?php echo esc_attr($settings['sec_class']);?>">
        <div class="swiper-container banner-slider">
            <div class="swiper-wrapper">
                <!-- Slide Item -->
				<?php foreach($settings['repeat'] as $item):?>	
                <div class="swiper-slide" style="background-image: url(<?php echo wp_get_attachment_url($item['block_bgimg']['id']);?>);">
                    <div class="content-outer">
                        <div class="content-box">
                            <div class="inner">
                                <h1><?php echo wp_kses($item['block_title'], $allowed_tags);?></h1>
                                <div class="text"><?php echo wp_kses($item['block_text'], $allowed_tags);?></div>
                                <div class="link-box">
                                    <a href="<?php echo esc_url($item['block_btnlink']['url']);?>" class="btn-1 btn-large"><?php echo wp_kses($item['block_button'], $allowed_tags);?><span></span></a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
				<?php endforeach; ?>
            </div>
        </div>
        <div class="banner-slider-nav">
            <div class="banner-slider-control banner-slider-button-prev"><span><i class="flaticon-left-arrow"></i></span></div>
            <div class="banner-slider-control banner-slider-button-next"><span><i class="flaticon-right-arrow"></i></span> </div>
        </div>
    </section>

             
		<?php 
	}

}