<?php

namespace KINGSTROXPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Testimonials_One extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'kingstrox_testimonials_one';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Testimonials One', 'kingstrox' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @since  2.0.0
	 * @access public
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'kingstrox' ];
	}
	
	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'testimonials_one',
			[
				'label' => esc_html__( 'Testimonials One', 'kingstrox' ),
			]
		);

		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => __( 'Sub Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Sub title', 'rashid' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);

		$this->add_control(
			'image',
				[
				  'label' => __( 'Image', 'rashid' ),
				  'type' => Controls_Manager::MEDIA,
				  'default' => ['url' => Utils::get_placeholder_image_src(),],
				]
		);	
		
		$this->add_control(
			'alt_text',
			[
				'label'       => __( 'Alt text', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Description', 'rashid' ),
			]
		);
		
		$this->end_controls_section();
		

		// New Tab#1

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Slider Block', 'kingstrox' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		  'repeat', 
			[
				'type' => Controls_Manager::REPEATER,
				'seperator' => 'before',
				'default' => 
					[
						['block_title' => esc_html__('Projects Completed', 'kingstrox')],
					],
				'fields' => 
					[				
							'block_icons'=>
						[
							'name' => 'block_icons',
							'label' => esc_html__('Enter The icons', 'rashid'),
							'type' => Controls_Manager::ICONS,							
						],

							'block_text'=>
						[
							'name' => 'block_text',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

							'block_image'=>
						[
							'name' => 'block_image',
							'label' => __( 'Image', 'rashid' ),
							'type' => Controls_Manager::MEDIA,
							'default' => ['url' => Utils::get_placeholder_image_src(),],
						],

							'block_alt_text'=>
						[
						  'name' => 'block_alt_text',
						  'label' => esc_html__('Image Text', 'rashid'),
						  'type' => Controls_Manager::TEXTAREA,
						  'default' => esc_html__('', 'rashid')
						],

							'block_title'=>
						[
							'name' => 'block_title',
							'label' => esc_html__('Title', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],
							
							'block_text2'=>
						[
							'name' => 'block_text2',
							'label' => esc_html__('Text', 'rashid'),
							'type' => Controls_Manager::TEXTAREA,
							'default' => esc_html__('', 'rashid')
						],

							'block_btnlink'=>
						[
							'name' => 'block_btnlink',
							'label' => __( 'Button Url', 'rashid' ),
							'type' => Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'rashid' ),
							'show_external' => true,
							'default' => [
							  'url' => '',
							  'is_external' => true,
							  'nofollow' => true,
							],
						],

						 	'block_image2'=>
						[
							 'name' => 'block_image2',
							 'label' => __( 'Image', 'rashid' ),
							 'type' => Controls_Manager::MEDIA,
							 'default' => ['url' => Utils::get_placeholder_image_src(),],
						],
 
							 'block_alt_text2'=>
						[
						   'name' => 'block_alt_text2',
						   'label' => esc_html__('Image Text', 'rashid'),
						   'type' => Controls_Manager::TEXTAREA,
						   'default' => esc_html__('', 'rashid')
						],


					],
				'title_field' => '{{block_title}}',
			 ]
			);
		
		
		$this->end_controls_section();	
			
	
		}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	 
	 protected function render() {
		$settings = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html('post');
		?>
        	

	<?php
	  echo '
	 <script>
 jQuery(document).ready(function($)
 {

//put the js code under this line 


// Testimonials Carousel
	if ($(".testimonial-carousel").length) {
		$(".testimonial-carousel").owlCarousel({
			loop:true,
			margin:30,
			nav:true,
			smartSpeed: 500,
			autoplay: true,
			responsive:{
				0:{
					items:1
				},
				764:{
					items:1
				},
				1024:{
					items:1
				}
			}
		});    		
	}

	// Sponsors Carousel
	if ($(".sponsors-carousel").length) {
		$(".sponsors-carousel").owlCarousel({
			loop:true,
			margin:30,
			nav:false,
			smartSpeed: 500,
			autoplay: true,
			responsive:{
				0:{
					items:1
				},
				480:{
					items:2
				},
				600:{
					items:3
				},
				768:{
					items:4
				},
				1024:{
					items:4
				}
			}
		});    		
	}


//put the code above the line 

  });
</script>';
?>

		 <!-- Testimonials and Clients -->
		 <section class="testimonials-and-clients <?php echo esc_attr($settings['sec_class']);?>">
        <div class="auto-container">
            <div class="row">
                <!-- Testimonial Column -->
                <div class="testimonial-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <div class="sec-title">
                            <span class="title"><?php echo $settings['subtitle'];?></span>
                            <h2><?php echo $settings['title'];?></h2>
                        </div>
                        <div class="testimonial-carousel owl-carousel owl-theme">
                            <!-- Testimonial BLock -->
							<?php foreach($settings['repeat'] as $key=>$item):?>
								<div class="testimonial-block">
									<div class="inner-box">
										<span class="<?php echo str_replace("icon ", " ", esc_attr( $item['block_icons']['value']));?>"></span>
										<div class="text"><?php echo wp_kses($item['block_text'], $allowed_tags);?></div>
										<div class="info-box">
											<div class="thumb">
												<?php if(wp_get_attachment_url($item['block_image']['id'])): ?>
													<img src="<?php echo wp_get_attachment_url($item['block_image']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text'], $allowed_tags);?>">
													<?php else :?>
													<div class="noimage"></div>
												<?php endif;?>
											</div>
											<h4 class="name"><?php echo wp_kses($item['block_title'], $allowed_tags);?></h4>
											<div class="rating">
												<?php echo wp_kses($item['block_text2'], $allowed_tags);?>
											</div>
										</div>
									</div>
								</div>
							<?php endforeach; ?>
                        </div>
                    </div>
                </div>

                <!-- Clients Column -->
                <div class="clients-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <div class="image-box wow fadeInRight">
                            <figure class="image">
								<?php  if ( esc_url($settings['image']['id']) ) : ?>   
									<img src="<?php echo wp_get_attachment_url($settings['image']['id']);?>" alt="<?php echo esc_attr($settings['alt_text']);?>"/>
									<?php else :?>
									<div class="noimage"></div>
								<?php endif;?>
							</figure>
                        </div>

                        <div class="sponsors-outer">
                            <!--Sponsors Carousel-->
                            <ul class="sponsors-carousel owl-carousel owl-theme">
								<?php foreach($settings['repeat'] as $key=>$item):?>
									<li class="slide-item">
										<figure class="image">
											<a href="<?php echo esc_url($item['block_btnlink']['url']);?>">
												<?php if(wp_get_attachment_url($item['block_image2']['id'])): ?>
													<img src="<?php echo wp_get_attachment_url($item['block_image2']['id']);?>" alt="<?php echo wp_kses($item['block_alt_text2'], $allowed_tags);?>">
													<?php else :?>
													<div class="noimage"></div>
												<?php endif;?>
											</a>
										</figure>
									</li>
								<?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!--End Testimonial and Clients -->

		<?php 
	}

}